<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class BLA_API {

	private $public_key;
	private $endpoint = "https://woocommerce-dev.blinfo.se/";

	function __construct( $public_key ){

		$this->public_key = $public_key;
	}

	private function call( $method, $data ){

		$url = $this->endpoint.$method;

		$response = wp_remote_post(
			$url,
			array(
				'method' => 'POST',
				'timeout' => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'blocking' => true,
				'headers' => array(),
				'body' => $data,
				'cookies' => array()
		    )
		);

		if ( is_wp_error( $response ) ) {
			return array(
				"status" => "error",
				"message" => $response->get_error_message()
			);
		} else {
			return json_decode( $response['body'], true );
		}

	}

	function sync_products( $products ){

		$data = array(
			"website" => get_bloginfo( "url" ),
			"public_key" => $this->public_key,
			"products" => $products
		);

		$response = $this->call( "sync/products", $data );

		return $response;
	}

	function sync_customer( $customer ){

		$data = array(
			"website" => get_bloginfo( "url" ),
			"public_key" => $this->public_key,
			"customer" => $customer
		);

		$response = $this->call( "sync/customer", $data );

		return $response;
	}

	function sync_order( $order ){

		$data = array(
			"website" => get_bloginfo( "url" ),
			"public_key" => $this->public_key,
			"order" => $order
		);

		$response = $this->call( "sync/orders", $data );

		return $response;
	}

}
