<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class BLA_Helpers {

	public static function generate_order_bla_id( $order_number ){

		$limit = 4;
		$length = strlen( $order_number );

		if( $length < $limit ) :
			for( $i=0;$i<$limit-$length;$i++):
				$order_number = "0".$order_number;
			endfor;
		endif;

		$bla_id = "WC_".$order_number;

		return $bla_id;
	}

	public static function get_product_data( $product_id ){

		$product = wc_get_product( $product_id );

		$product_formatted = array();

		$product_formatted["wp_id"] = $product->get_id();
		$product_formatted["new_bla_id"] = $product->get_sku()?$product->get_sku():$product->get_id()."-AUTO";
		$product_formatted["old_bla_id"] = get_post_meta( $product_id, "_bla_id", true );
		$product_formatted["name"] = $product->get_title();
		$product_formatted["stock"] = (int)$product->get_stock_quantity();
		$product_formatted["price"] = (float)self::get_price_excluding_tax( $product );
		$product_formatted["vat"] = get_option( "bla_tax_" . ( $product->get_tax_class() ? $product->get_tax_class() : "standard" ) );
		if ( $product_formatted["vat"] == '25' ) {
			$product_formatted["vat"] = '1';
		}
		if ( $product_formatted["vat"] == '12' ) {
			$product_formatted["vat"] = '2';
		}
		if ( $product_formatted["vat"] == '6' ) {
			$product_formatted["vat"] = '3';
		}
		if ( $product_formatted["vat"] == '0' ) {
			$product_formatted["vat"] = '4';
		}
		$product_formatted["weight"] = (float)$product->get_weight();
		$product_formatted["parent_wp_id"] = $product->get_parent_id();

		return $product_formatted;
	}

	public function get_price_excluding_tax( $product )
	{
		$return_price = $product->get_regular_price();

		if ( $product->is_taxable() && wc_prices_include_tax() ) {
			$tax_rates      = WC_Tax::get_rates( $product->get_tax_class() );
			$base_tax_rates = WC_Tax::get_base_tax_rates( $product->get_tax_class( 'unfiltered' ) );
			$remove_taxes   = apply_filters( 'woocommerce_adjust_non_base_location_prices', true ) ? WC_Tax::calc_tax( $return_price, $base_tax_rates, true ) : WC_Tax::calc_tax( $return_price, $tax_rates, true );
			$return_price   = $return_price - array_sum( $remove_taxes ); // Unrounded since we're dealing with tax inclusive prices. Matches logic in cart-totals class. @see adjust_non_base_location_price.
		}

		return $return_price;
	}

	public static function get_customer_data( $order_id )
	{
		$order = new WC_Order( $order_id );
		$order_data = $order->get_data();

		$customer_id = (int)$order->get_customer_id();

		$customer_formatted = array(
			"wp_id" => $customer_id,
			"name" => trim( $order_data["billing"]["first_name"] . " " .$order_data["billing"]["last_name"] ),
			"email" => $order_data["billing"]["email"],
			"city" => $order_data["billing"]["city"],
			"address" => trim( $order_data["billing"]["address_1"] . " " .$order_data["billing"]["address_2"] ),
			"zip" => $order_data["billing"]["postcode"],
			"phone" => $order_data["billing"]["phone"],
			"country" => $order_data["billing"]["country"]
		);

		return $customer_formatted;

	}

	public static function get_order_data( $order_id )
	{
		$order = new WC_Order( $order_id );

		if( !$order ) return array();
		
		$order_data = $order->get_data();

		$customer_id = (int)$order->get_customer_id();

		$order_formatted = array(
			"wp_id" => $order_id,
			"customer" => BLA_Helpers::get_customer_data($order_id),
			"currency" => $order->get_currency(),
			"name" => trim( $order_data["billing"]["first_name"] . " " .$order_data["billing"]["last_name"] ),
			"old_bla_id" => get_post_meta( $order_id, "_bla_id", true ),
			"email" => $order_data["billing"]["email"],
			"billing_city" => $order_data["billing"]["city"],
			"billing_address" => trim( $order_data["billing"]["address_1"] . " " .$order_data["billing"]["address_2"] ),
			"billing_zip" => $order_data["billing"]["postcode"],
			"billing_country" => $order_data["billing"]["country"],
			"shipping_city" => $order_data["shipping"]["city"],
			"shipping_address" => trim( $order_data["shipping"]["address_1"] . " " .$order_data["shipping"]["address_2"] ),
			"shipping_zip" => $order_data["shipping"]["postcode"],
			"shipping_country" => $order_data["shipping"]["country"],
			"phone" => $order_data["billing"]["phone"],
			"shipping_cost" => $order->get_total_shipping(),
			"shipping_method" => $order->get_shipping_method(),
			"date" => date( "Y-m-d", strtotime($order->order_date) ),
			"products" => array()
		);


		foreach( $order->get_items() as $line_item ) :
            $real_product_id = $line_item->get_variation_id()?$line_item->get_variation_id():$line_item->get_product_id();
            $product = wc_get_product( $real_product_id );
           	$order_formatted["products"][] = array(
           		"data" => BLA_Helpers::get_product_data($real_product_id),
           		"quantity" => $line_item->get_quantity(),
           		"price" => $line_item->get_subtotal()/$line_item->get_quantity(),
           		"discount" => $line_item->get_subtotal()/$line_item->get_quantity() - $product->get_price()
           	);
        endforeach;

		return $order_formatted;

	}

	public static function get_products_to_sync(){

		$args = array(
		    'status' => 'publish',
		    'type' => array( 'simple', 'variable' )
		);

		$all_products = wc_get_products( $args );
		$syncable_products = array();

		foreach( $all_products as $product ) :

			switch( $product->get_type() ) :

				case "simple" :

					if( BLA_Helpers::should_product_be_synced( $product->get_id() ) ) :
						$syncable_products[] = $product->get_id();
					endif;

				break;

				case "variable" :

					foreach( $product->get_children() as $variation_id ) :

						if( BLA_Helpers::should_product_be_synced( $variation_id ) ) :
							$syncable_products[] = $variation_id;
						endif;

					endforeach;

				break;

			endswitch;
		endforeach;

		return $syncable_products;
	}

	public static function should_product_be_synced( $product_id ){

		return !get_post_meta( $product_id, "_bla_id", true ) || get_post_meta( $product_id, "_bla_last_synced", true ) < get_post_meta( $product_id, "_bla_modified_date", true );
	}
}
